use macro_rules_attribute::macro_rules_derive;
use schemars::JsonSchema;
use serde::Deserialize;

use crate::{
    macros::DefDer,
    types::{
        dns::Dns,
        structs::DnsToken,
        traits::DnsHandler,
    },
};

#[macro_rules_derive(DefDer)]
#[derive(Deserialize, JsonSchema)]
#[serde(deny_unknown_fields)]
pub struct DNSUpdateClientOptions {}

impl DNSUpdateClientOptions {
    pub fn build(self, _zone: String) -> Dns {
        Dns::DNSUpdate(DnsUpdateHandler {})
    }
}

#[macro_rules_derive(DefDer)]
pub struct DnsUpdateHandler {}

impl DnsHandler for DnsUpdateHandler {
    async fn set_record(&self, _domain: String, _content: String) -> crate::types::Result<DnsToken> {
        Ok(DnsToken::new_dns_update())
    }
}

#[macro_rules_derive(DefDer)]
pub struct DnsUpdateToken {}

impl DnsUpdateToken {
    pub async fn remove(&mut self) {}
}

unsafe impl Send for DnsUpdateToken {}
